@@ -9,8 +9,8 @@ MWI<-function (itemBank, item, x, it, lower = -4, upper = 4, nqp = 33,
         par)$Pi)^(1 - x))
     X <- seq(from = lower, to = upper, length = nqp)
     ITEMS <- NULL
-    for (i in 1:length(X)) ITEMS[i] <- min((1:length(itemBank$theta))[(itemBank$theta - 
-        X[i]) == min(itemBank$theta - X[i])])
+    for (i in 1:length(X)) ITEMS[i] <- min((1:length(itemBank$theta))[abs(itemBank$theta - 
+        X[i]) == min(abs(itemBank$theta - X[i]))])
     if (type == "MPWI"){
        Z<-switch(priorDist,norm=dnorm(X, priorPar[1], priorPar[2]),unif=dunif(X, priorPar[1], priorPar[2]))
         Y <- itemBank$infoTab[ITEMS, item] * sapply(X, L, x, 
